/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.se.validation.model;

import java.util.concurrent.atomic.AtomicInteger;

/**
 * A bean to store configuration elements for Validation service-unit.
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class ValidationConfiguration {

	/**
	 * Static integer used to generate identifiers.
	 */
	private static AtomicInteger idCounter = new AtomicInteger();

	/**
	 * The configuration identifier (generated, never null).
	 */
	private final int id;

	/**
	 * The path of the XML schema in the SU directory.
	 */
	private final String xsdPath;

	/**
	 * The path of the SU root directory.
	 */
	private final String suInstallRoot;

	/**
	 * The end-point name associated with this configuration.
	 */
	private final String endpointName;

	/**
	 * The service-unit associated with this configuration.
	 */
	private final String serviceUnitName;


	/**
	 * Constructor.
	 * @param xsdPath the path to the XML schema
	 * @param suInstallRoot the path of the SU root directory
	 * @param endpointName the end-point name
	 * @param serviceUnitName the service-unit name
	 */
	public ValidationConfiguration(
			String xsdPath,
			String suInstallRoot,
			String endpointName,
			String serviceUnitName ) {

		// Create the ID
		this.id = idCounter.getAndIncrement();

		// Store values
		this.xsdPath = xsdPath;
		this.suInstallRoot = suInstallRoot;
		this.endpointName = endpointName;
		this.serviceUnitName = serviceUnitName;
	}


	/**
	 * @return the xsdPath
	 */
	public String getXsdPath() {
		return this.xsdPath;
	}


	/**
	 * @return the suInstallRoot
	 */
	public String getSuInstallRoot() {
		return this.suInstallRoot;
	}


	/**
	 * @return the endpointName
	 */
	public String getEndpointName() {
		return this.endpointName;
	}


	/**
	 * @return the serviceUnitName
	 */
	public String getServiceUnitName() {
		return this.serviceUnitName;
	}


	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals( Object obj ) {

		return obj != null
		&& obj instanceof ValidationConfiguration
		&& ((ValidationConfiguration) obj).id == this.id;
	}


	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		return this.id;
	}
}
