/**
 * Copyright (c) 2008-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.se.validation.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.w3c.dom.ls.LSInput;
import org.w3c.dom.ls.LSResourceResolver;

/**
 * @author Mathias Beldame - EBM WebSourcing
 */
public class XsdResourceResolver implements LSResourceResolver {

	private String resourcesBase = "";
	private final Logger logger;

	/**
	 * Constructor.
	 * @param resourcesBase
	 * @param logger
	 */
	public XsdResourceResolver(String resourcesBase, Logger logger) {
		this.logger = logger;
		this.resourcesBase = resourcesBase;

		logger.finest("XSD imports will be searched in " + resourcesBase);
	}

	/*
	 * (non-Javadoc)
	 * @see org.w3c.dom.ls.LSResourceResolver
	 * #resolveResource(java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String)
	 */
	public LSInput resolveResource(String type, String namespaceURI, String publicId, String systemId, String baseURI) {

		final LSInput resource = new LSInputImpl();
		try {
			this.logger.finest("load XSD import " + this.resourcesBase + systemId);
			resource.setByteStream(new FileInputStream(new File(this.resourcesBase, systemId)));

		} catch (final FileNotFoundException fnfe) {
			this.logger.log(Level.SEVERE, "can not load XSD import " + fnfe.getMessage(), fnfe);
		}

		return resource;
	}
}
